@@ -251,7 +251,7 @@ seek_to_pos (TotemBemusedPlugin *tp, GIOChannel *source)
 	time += buf[2] << 8;
 	time += buf[3];
 
-	totem_action_seek_time (tp->totem, (gint64) time * 1000);
+	totem_action_seek_time (tp->totem, (gint64) time * 1000, FALSE);
 }
 
 static void
@@ -302,7 +302,7 @@ download_file (TotemBemusedPlugin *tp, GIOChannel *source)
 		return;
 	send_response_flush (tp, source, "DOWNACK", strlen ("DOWNACK"), FALSE);
 	send_response (tp, source, g_mapped_file_get_contents (file), g_mapped_file_get_length (file));
-	g_mapped_file_free (file);
+	g_mapped_file_unref (file);
 }
 
 #define STUFF4(x) {						\
@@ -413,7 +413,6 @@ static void
 write_directory_listing (TotemBemusedPlugin *tp, GIOChannel *source, gboolean at_root)
 {
 	char *filename;
-	char *root;
 	char buf[2];
 
 	if (at_root == FALSE)
