@@ -24,6 +24,7 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
+#include <gst/tag/tag.h>
 #include <string.h>
 
 #include "totem-menu.h"
@@ -72,7 +73,6 @@ G_MODULE_EXPORT void about_action_callback (GtkAction *action, Totem *totem);
 G_MODULE_EXPORT void plugins_action_callback (GtkAction *action, Totem *totem);
 G_MODULE_EXPORT void repeat_mode_action_callback (GtkToggleAction *action, Totem *totem);
 G_MODULE_EXPORT void shuffle_mode_action_callback (GtkToggleAction *action, Totem *totem);
-G_MODULE_EXPORT void deinterlace_action_callback (GtkToggleAction *action, Totem *totem);
 G_MODULE_EXPORT void show_controls_action_callback (GtkToggleAction *action, Totem *totem);
 G_MODULE_EXPORT void show_sidebar_action_callback (GtkToggleAction *action, Totem *totem);
 G_MODULE_EXPORT void aspect_ratio_changed_callback (GtkRadioAction *action, GtkRadioAction *current, Totem *totem);
@@ -93,157 +93,6 @@ escape_label_for_menu (const char *name)
 	return new;
 }
 
-/* ISO-639 helpers */
-static GHashTable *lang_table;
-
-static void
-totem_lang_table_free (void)
-{
-	g_hash_table_destroy (lang_table);
-	lang_table = NULL;
-}
-
-static void
-totem_lang_table_parse_start_tag (GMarkupParseContext *ctx,
-		const gchar         *element_name,
-		const gchar        **attr_names,
-		const gchar        **attr_values,
-		gpointer             data,
-		GError             **error)
-{
-	const char *ccode_longB, *ccode_longT, *ccode, *lang_name;
-
-	if (!g_str_equal (element_name, "iso_639_entry")
-			|| attr_names == NULL
-			|| attr_values == NULL)
-		return;
-
-	ccode = NULL;
-	ccode_longB = NULL;
-	ccode_longT = NULL;
-	lang_name = NULL;
-
-	while (*attr_names && *attr_values)
-	{
-		if (g_str_equal (*attr_names, "iso_639_1_code"))
-		{
-			/* skip if empty */
-			if (**attr_values)
-			{
-				g_return_if_fail (strlen (*attr_values) == 2);
-				ccode = *attr_values;
-			}
-		} else if (g_str_equal (*attr_names, "iso_639_2B_code")) {
-			/* skip if empty */
-			if (**attr_values)
-			{
-				g_return_if_fail (strlen (*attr_values) == 3 || strcmp (*attr_values, "qaa-qtz") == 0);
-				ccode_longB = *attr_values;
-			}
-		} else if (g_str_equal (*attr_names, "iso_639_2T_code")) {
-			/* skip if empty */
-			if (**attr_values)
-			{
-				g_return_if_fail (strlen (*attr_values) == 3 || strcmp (*attr_values, "qaa-qtz") == 0);
-				ccode_longT = *attr_values;
-			}
-		} else if (g_str_equal (*attr_names, "name")) {
-			lang_name = *attr_values;
-		}
-
-		++attr_names;
-		++attr_values;
-	}
-
-	if (lang_name == NULL)
-		return;
-
-	if (ccode != NULL)
-	{
-		g_hash_table_insert (lang_table,
-				g_strdup (ccode),
-				g_strdup (lang_name));
-	}
-	if (ccode_longB != NULL)
-	{
-		g_hash_table_insert (lang_table,
-				g_strdup (ccode_longB),
-				g_strdup (lang_name));
-	}
-	if (ccode_longT != NULL)
-	{
-		g_hash_table_insert (lang_table,
-				g_strdup (ccode_longT),
-				g_strdup (lang_name));
-	}
-}
-
-#define ISO_CODES_DATADIR ISO_CODES_PREFIX"/share/xml/iso-codes"
-#define ISO_CODES_LOCALESDIR ISO_CODES_PREFIX"/share/locale"
-
-static void
-totem_lang_table_init (void)
-{
-	GError *err = NULL;
-	char *buf;
-	gsize buf_len;
-
-	lang_table = g_hash_table_new_full
-		(g_str_hash, g_str_equal, g_free, g_free);
-
-	g_atexit (totem_lang_table_free);
-
-	bindtextdomain ("iso_639", ISO_CODES_LOCALESDIR);
-	bind_textdomain_codeset ("iso_639", "UTF-8");
-
-	if (g_file_get_contents (ISO_CODES_DATADIR "/iso_639.xml",
-				&buf, &buf_len, &err))
-	{
-		GMarkupParseContext *ctx;
-		GMarkupParser parser =
-		{ totem_lang_table_parse_start_tag, NULL, NULL, NULL, NULL };
-
-		ctx = g_markup_parse_context_new (&parser, 0, NULL, NULL);
-
-		if (!g_markup_parse_context_parse (ctx, buf, buf_len, &err))
-		{
-			g_warning ("Failed to parse '%s': %s\n",
-					ISO_CODES_DATADIR"/iso_639.xml",
-					err->message);
-			g_error_free (err);
-		}
-
-		g_markup_parse_context_free (ctx);
-		g_free (buf);
-	} else {
-		g_warning ("Failed to load '%s': %s\n",
-				ISO_CODES_DATADIR"/iso_639.xml", err->message);
-		g_error_free (err);
-	}
-}
-
-static const char *
-totem_lang_get_full (const char *lang)
-{
-	const char *lang_name;
-	int len;
-
-	g_return_val_if_fail (lang != NULL, NULL);
-
-	len = strlen (lang);
-	if (len != 2 && len != 3)
-		return NULL;
-	if (lang_table == NULL)
-		totem_lang_table_init ();
-
-	lang_name = (const gchar*) g_hash_table_lookup (lang_table, lang);
-
-	if (lang_name)
-		return dgettext ("iso_639", lang_name);
-
-	return NULL;
-}
-
 /* Subtitle and language menus */
 static void
 totem_g_list_deep_free (GList *list)
@@ -289,7 +138,7 @@ add_lang_action (Totem *totem, GtkActionGroup *action_group, guint ui_id,
 	GtkAction *action;
 	guint i;
 
-	full_lang = totem_lang_get_full (lang);
+	full_lang = gst_tag_get_language_name (lang);
 
 	if (lang_index > 1) {
 		char *num_lang;
@@ -516,10 +365,6 @@ connect_proxy_cb (GtkActionGroup *action_group,
                   gpointer data)
 {
         GtkLabel *label;
-        GtkRecentInfo *recent_info;
-        GdkPixbuf *icon;
-        GtkWidget *image = NULL;
-        gint w, h;
 
         if (!GTK_IS_MENU_ITEM (proxy))
                 return;
@@ -528,23 +373,6 @@ connect_proxy_cb (GtkActionGroup *action_group,
 
         gtk_label_set_ellipsize (label, PANGO_ELLIPSIZE_MIDDLE);
         gtk_label_set_max_width_chars (label,TOTEM_MAX_RECENT_ITEM_LEN);
-
-        if (!GTK_IS_IMAGE_MENU_ITEM (proxy))
-                return;
-
-        recent_info = g_object_get_data (G_OBJECT (action), "recent-info");
-        g_assert (recent_info != NULL);
-
-        gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &w, &h);
-
-        icon = gtk_recent_info_get_icon (recent_info, w);
-        if (icon != NULL) {
-                image = gtk_image_new_from_pixbuf (icon);
-                g_object_unref (icon);
-        }
-
-        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (proxy), image);
-        gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (proxy), TRUE);
 }
 
 static void
@@ -634,6 +462,9 @@ totem_recent_manager_changed_callback (GtkRecentManager *recent_manager, Totem *
                 const char    *display_name;
                 char          *label;
                 char          *escaped_label;
+                const gchar   *mime_type;
+                gchar         *content_type;
+                GIcon         *icon = NULL;
 
                 info = (GtkRecentInfo *) l->data;
 
@@ -656,6 +487,18 @@ totem_recent_manager_changed_callback (GtkRecentManager *recent_manager, Totem *
                                   G_CALLBACK (on_recent_file_item_activated),
                                   totem);
 
+                mime_type = gtk_recent_info_get_mime_type (info);
+                content_type = g_content_type_from_mime_type (mime_type);
+                if (content_type != NULL) {
+                        icon = g_content_type_get_icon (content_type);
+                        g_free (content_type);
+                }
+                if (icon != NULL) {
+                        gtk_action_set_gicon (action, icon);
+                        gtk_action_set_always_show_image (action, TRUE);
+                        g_object_unref (icon);
+                }
+
                 gtk_action_group_add_action (totem->recent_action_group,
                                             action);
                 g_object_unref (action);
@@ -1276,13 +1119,13 @@ previous_chapter_action_callback (GtkAction *action, Totem *totem)
 void
 skip_forward_action_callback (GtkAction *action, Totem *totem)
 {
-	totem_action_seek_relative (totem, SEEK_FORWARD_OFFSET * 1000);
+	totem_action_seek_relative (totem, SEEK_FORWARD_OFFSET * 1000, FALSE);
 }
 
 void
 skip_backwards_action_callback (GtkAction *action, Totem *totem)
 {
-	totem_action_seek_relative (totem, SEEK_BACKWARD_OFFSET * 1000);
+	totem_action_seek_relative (totem, SEEK_BACKWARD_OFFSET * 1000, FALSE);
 }
 
 void
@@ -1414,17 +1257,6 @@ shuffle_mode_action_callback (GtkToggleAction *action, Totem *totem)
 			gtk_toggle_action_get_active (action));
 }
 
-void
-deinterlace_action_callback (GtkToggleAction *action, Totem *totem)
-{
-	gboolean value;
-
-	value = gtk_toggle_action_get_active (action);
-	bacon_video_widget_set_deinterlacing (totem->bvw, value);
-	gconf_client_set_bool (totem->gc, GCONF_PREFIX"/deinterlace",
-			value, NULL);
-}
-
 void
 show_controls_action_callback (GtkToggleAction *action, Totem *totem)
 {
