@@ -48,7 +48,8 @@
 G_MODULE_EXPORT void checkbutton1_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
 G_MODULE_EXPORT void checkbutton2_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
 G_MODULE_EXPORT void checkbutton3_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
-G_MODULE_EXPORT void checkbutton4_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
+G_MODULE_EXPORT void audio_screensaver_button_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
+G_MODULE_EXPORT void no_deinterlace_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
 G_MODULE_EXPORT void remember_position_checkbutton_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
 G_MODULE_EXPORT void connection_combobox_changed (GtkComboBox *combobox, Totem *totem);
 G_MODULE_EXPORT void visual_menu_changed (GtkComboBox *combobox, Totem *totem);
@@ -186,15 +187,52 @@ checkbutton3_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
 }
 
 void
-checkbutton4_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
+audio_screensaver_button_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
 {
 	gboolean value;
 
 	value = gtk_toggle_button_get_active (togglebutton);
 
 	gconf_client_set_bool (totem->gc,
-			       GCONF_PREFIX"/lock_screensaver_on_audio", 
-			       !value, NULL);
+			       GCONF_PREFIX"/lock_screensaver_on_audio",
+			       value, NULL);
+}
+
+void
+no_deinterlace_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
+{
+	gboolean value;
+
+	value = gtk_toggle_button_get_active (togglebutton);
+
+	bacon_video_widget_set_deinterlacing (totem->bvw, !value);
+	gconf_client_set_bool (totem->gc,
+			       GCONF_PREFIX"/disable_deinterlacing",
+			       value, NULL);
+}
+
+static void
+no_deinterlace_changed_cb (GConfClient *client,
+			   guint cnxn_id,
+			   GConfEntry *entry,
+			   Totem *totem)
+{
+	GObject *button;
+	gboolean value;
+
+	button = gtk_builder_get_object (totem->xml, "tpw_no_deinterlace_checkbutton");
+
+	g_signal_handlers_block_matched (button,
+					 G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, totem);
+
+	value = gconf_client_get_bool (totem->gc,
+				       GCONF_PREFIX"/disable_deinterlacing", NULL);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), value);
+	bacon_video_widget_set_deinterlacing (totem->bvw, !value);
+
+	g_signal_handlers_unblock_matched (button,
+					   G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, totem);
 }
 
 void
@@ -210,26 +248,6 @@ remember_position_checkbutton_toggled_cb (GtkToggleButton *togglebutton, Totem *
 	totem->remember_position = value;
 }
 
-static void
-deinterlace_changed_cb (GConfClient *client, guint cnxn_id,
-		GConfEntry *entry, Totem *totem)
-{
-	GtkAction *action;
-
-	action = gtk_action_group_get_action (totem->main_action_group,
-			"deinterlace");
-
-	g_signal_handlers_block_matched (G_OBJECT (action),
-			G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, totem);
-
-	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
-			gconf_client_get_bool (totem->gc,
-				GCONF_PREFIX"/deinterlace", NULL));
-
-	g_signal_handlers_unblock_matched (G_OBJECT (action),
-			G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, totem);
-}
-
 static void
 remember_position_changed_cb (GConfClient *client, guint cnxn_id,
                               GConfEntry *entry, Totem *totem)
@@ -298,18 +316,24 @@ static void
 lock_screensaver_on_audio_changed_cb (GConfClient *client, guint cnxn_id,
 				      GConfEntry *entry, Totem *totem)
 {
-	GObject *item;
+	GObject *item, *radio;
+	gboolean value;
 
-	item = gtk_builder_get_object (totem->xml, "tpw_screensaver_checkbutton");
+	item = gtk_builder_get_object (totem->xml, "tpw_audio_toggle_button");
 	g_signal_handlers_disconnect_by_func (item,
-					      checkbutton4_toggled_cb, totem);
+					      audio_screensaver_button_toggled_cb, totem);
 
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item),
-				      !gconf_client_get_bool (totem->gc,
-							      GCONF_PREFIX"/lock_screensaver_on_audio", NULL));
+	value = gconf_client_get_bool (totem->gc,
+				       GCONF_PREFIX"/lock_screensaver_on_audio", NULL);
+	if (value != FALSE) {
+		radio = gtk_builder_get_object (totem->xml, "tpw_audio_toggle_button");
+	} else {
+		radio = gtk_builder_get_object (totem->xml, "tpw_video_toggle_button");
+	}
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
 
 	g_signal_connect (item, "toggled",
-			  G_CALLBACK (checkbutton4_toggled_cb), totem);
+			  G_CALLBACK (audio_screensaver_button_toggled_cb), totem);
 }
 
 static void
@@ -503,8 +527,7 @@ void
 totem_setup_preferences (Totem *totem)
 {
 	GtkWidget *menu, *content_area;
-	GtkAction *action;
-	gboolean show_visuals, auto_resize, is_local, deinterlace, lock_screensaver_on_audio;
+	gboolean show_visuals, auto_resize, is_local, no_deinterlace, lock_screensaver_on_audio;
 	int connection_speed;
 	guint i, hidden;
 	char *visual, *font, *encoding;
@@ -581,12 +604,25 @@ totem_setup_preferences (Totem *totem)
 	/* Screensaver audio locking */
 	lock_screensaver_on_audio = gconf_client_get_bool (totem->gc,
 							   GCONF_PREFIX"/lock_screensaver_on_audio", NULL);
-	item = gtk_builder_get_object (totem->xml, "tpw_screensaver_checkbutton");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), !lock_screensaver_on_audio);
+	if (lock_screensaver_on_audio != FALSE)
+		item = gtk_builder_get_object (totem->xml, "tpw_audio_toggle_button");
+	else
+		item = gtk_builder_get_object (totem->xml, "tpw_video_toggle_button");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), TRUE);
 	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/lock_screensaver_on_audio",
 				 (GConfClientNotifyFunc) lock_screensaver_on_audio_changed_cb,
 				 totem, NULL, NULL);
 
+	/* Disable deinterlacing */
+	item = gtk_builder_get_object (totem->xml, "tpw_no_deinterlace_checkbutton");
+	no_deinterlace = gconf_client_get_bool (totem->gc,
+						GCONF_PREFIX"/disable_deinterlacing", NULL);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), no_deinterlace);
+	bacon_video_widget_set_deinterlacing (totem->bvw, !no_deinterlace);
+	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/disable_deinterlacing",
+				 (GConfClientNotifyFunc) no_deinterlace_changed_cb,
+				 totem, NULL, NULL);
+
 	/* Connection Speed */
 	connection_speed = bacon_video_widget_get_connection_speed (totem->bvw);
 	item = gtk_builder_get_object (totem->xml, "tpw_speed_combobox");
@@ -684,19 +720,6 @@ totem_setup_preferences (Totem *totem)
 	audio_out = bacon_video_widget_get_audio_out_type (totem->bvw);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (item), audio_out);
 
-	/* This one is for the deinterlacing menu, not really our dialog
-	 * but we do it anyway */
-	action = gtk_action_group_get_action (totem->main_action_group,
-			"deinterlace");
-	deinterlace = gconf_client_get_bool (totem->gc,
-			GCONF_PREFIX"/deinterlace", NULL);
-	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
-			deinterlace);
-	bacon_video_widget_set_deinterlacing (totem->bvw, deinterlace);
-	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/deinterlace",
-			(GConfClientNotifyFunc) deinterlace_changed_cb,
-			totem, NULL, NULL);
-
 	/* Subtitle font selection */
 	item = gtk_builder_get_object (totem->xml, "font_sel_button");
 	gtk_font_button_set_title (GTK_FONT_BUTTON (item),
