@@ -31,7 +31,6 @@
 #include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 #include <gio/gio.h>
-#include <unique/uniqueapp.h>
 
 #include "totem-playlist.h"
 #include "bacon-video-widget.h"
@@ -51,9 +50,9 @@
 
 #define totem_action_set_sensitivity(name, state)					\
 	{										\
-		GtkAction *action;							\
-		action = gtk_action_group_get_action (totem->main_action_group, name);	\
-		gtk_action_set_sensitive (action, state);				\
+		GtkAction *__action;							\
+		__action = gtk_action_group_get_action (totem->main_action_group, name);\
+		gtk_action_set_sensitive (__action, state);				\
 	}
 
 typedef enum {
@@ -69,7 +68,7 @@ typedef enum {
 	STATE_STOPPED
 } TotemStates;
 
-struct TotemObject {
+struct _TotemObject {
 	GObject parent;
 
 	/* Control window */
@@ -145,7 +144,7 @@ struct TotemObject {
 
 	/* session */
 	const char *argv0;
-	gint64 seek_to;
+	gint64 seek_to_start;
 	guint index;
 	gboolean session_restored;
 
@@ -155,11 +154,14 @@ struct TotemObject {
 
 	/* other */
 	char *mrl;
+	gint64 seek_to;
 	TotemPlaylist *playlist;
 	GConfClient *gc;
-	UniqueApp *app;
+	GApplication *app;
 	TotemStates state;
 	TotemOpenLocation *open_location;
+	gboolean remember_position;
+	gboolean disable_kbd_shortcuts;
 };
 
 GtkWidget *totem_volume_create (void);
